@@ -19,7 +19,7 @@ class TestRunner(object):
 		assert isinstance(processes, dict)
 		for process in processes:
 			process_dict = processes[process]
-			assert 'memory:mb' in process_dict
-			assert 'cpu:%' in process_dict
+			assert 'memory_mb' in process_dict
+			assert 'cpu' in process_dict
 
 
